@@ -7,6 +7,7 @@ import contextlib
 import importlib
 from collections import OrderedDict
 
+from pylibimp import original_system, import_module
 from pylibimport.utils import get_name_version
 from pylibimport.run_pip import default_wait_func, pip_main
 
@@ -20,58 +21,6 @@ class InstallError(Exception):
     pass
 
 
-@contextlib.contextmanager
-def original_system(new_path=None, reset_modules=True):
-    """Context manager to reset sys.path and sys.modules to the previous state before the context operation.
-
-    Args:
-        new_path (str)[None]: Temporarily add a path to sys.path before the operation.
-        reset_modules (bool)[True]: If True reset sys.modules back to the original sys.modules.
-    """
-    modules = sys.modules.copy()
-    paths = copy.copy(sys.path)
-    path_cache = sys.path_importer_cache.copy()
-
-    # Temporarily add the new path
-    if new_path and new_path not in sys.path:
-        sys.path.insert(0, new_path)
-
-    yield
-
-    if reset_modules:
-        # sys.modules = modules  # For some reason this causes conflicts with relative imports?
-        sys.modules.clear()
-        sys.modules.update(modules)
-    sys.path = paths
-    sys.path_importer_cache = path_cache
-
-
-def import_module(path, import_chain=None, reset_modules=True):
-    """Import the given module name from the given import path.
-
-    Args:
-        path (str): Directory which contains the module to import.
-        import_chain (str): Chain to import with.
-        reset_modules (bool)[True]: If True reset sys.modules back to the original sys.modules.
-
-    Returns:
-        module (ModuleType): Module object that was imported.
-
-    Raises:
-        ImportError: If the import is unsuccessful.
-    """
-    if import_chain is None:
-        import_chain, _ = get_name_version(path)
-    if os.path.isfile(path):
-        path = os.path.dirname(path)
-
-    if os.path.exists(path):
-        # Import the module
-        with original_system(os.path.abspath(path), reset_modules=reset_modules):
-            module = importlib.import_module(import_chain)  # module = __import__(name)
-        return module
-
-
 INSTALL_TYPES = OrderedDict()
 
 
@@ -240,7 +189,7 @@ def zip_install(path, dest, *args, **kwargs):
 
 @register_install_type('.whl')
 def whl_install(path, dest, *args, pip=None, extra_install_args=None, install_dependencies=False, wait_func=None,
-                reset_modules=True, **kwargs):
+                reset_modules=True, contained_modules=None, **kwargs):
     """Import whl or zip files and return the installed module.
 
     Args:
@@ -253,6 +202,7 @@ def whl_install(path, dest, *args, pip=None, extra_install_args=None, install_de
         install_dependencies (bool)[False]: If True .whl files will install dependencies into the install_dir.
         wait_func (callable/function)[None]: Function called while waiting for pip to finish (passed into pip).
         reset_modules (bool)[True]: If True reset sys.modules back to the original sys.modules.
+        contained_modules (dict)[None]: If given and reset_modules save all imported modules to this dictionary.
 
     Returns:
         installed (bool): If True it was installed this time. If False directory already existed.
@@ -271,7 +221,7 @@ def whl_install(path, dest, *args, pip=None, extra_install_args=None, install_de
         os.makedirs(dest, exist_ok=True)
     except:
         pass
-    with original_system(dest, reset_modules=reset_modules):
+    with original_system(dest, reset_modules=reset_modules, contained_modules=contained_modules):
         args = ['install', '--target', dest] + extra_install_args + [path]
         if not install_dependencies:
             args.insert(1, '--no-deps')
